@@ -3,5 +3,5 @@
 # @email: maoyongfan@163.com
 # @Date: 2024/12/25 15:08
 # 检测crc
-from .crc import CRC16X25, cal_msg_crc
+from .crc import CRC16X25, cal_msg_crc, cal_img_crc
 
