@@ -2,5 +2,5 @@
 # @Author: maoyongfan
 # @email: maoyongfan@163.com
 # @Date: 2025/2/28 23:04
-from .datetime_change import timeDifference_seconds, get_localTime, get_strftime
+from .datetime_change import timeDifference_seconds, get_localTime, get_strftime, get_utc_seconds
 
